=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2008-07-14 07:47:45 +0000
+++ bzrlib/branch.py	2008-07-15 04:43:19 +0000
@@ -331,14 +331,14 @@
             raise errors.InvalidRevisionNumber(revno)
         return self.repository.get_revision_delta(rh[revno-1])
 
-    def get_stacked_on(self):
+    def get_stacked_on_url(self):
         """Get the URL this branch is stacked against.
 
         :raises NotStacked: If the branch is not stacked.
         :raises UnstackableBranchFormat: If the branch does not support
             stacking.
         """
-        raise NotImplementedError(self.get_stacked_on)
+        raise NotImplementedError(self.get_stacked_on_url)
 
     def print_file(self, file, revision_id):
         """Print `file` to stdout."""
@@ -1837,7 +1837,7 @@
         except errors.InvalidURLJoin, e:
             raise errors.InaccessibleParent(parent, self.base)
 
-    def get_stacked_on(self):
+    def get_stacked_on_url(self):
         raise errors.UnstackableBranchFormat(self._format, self.base)
 
     def set_push_location(self, location):
@@ -2016,7 +2016,7 @@
 
     def _open_hook(self):
         try:
-            url = self.get_stacked_on()
+            url = self.get_stacked_on_url()
         except (errors.UnstackableRepositoryFormat, errors.NotStacked,
             errors.UnstackableBranchFormat):
             pass
@@ -2178,7 +2178,7 @@
         """See Branch.get_old_bound_location"""
         return self._get_bound_location(False)
 
-    def get_stacked_on(self):
+    def get_stacked_on_url(self):
         self._check_stackable_repo()
         stacked_url = self._get_config_location('stacked_on_location')
         if stacked_url is None:
@@ -2197,7 +2197,7 @@
         self._check_stackable_repo()
         if not url:
             try:
-                old_url = self.get_stacked_on()
+                old_url = self.get_stacked_on_url()
             except (errors.NotStacked, errors.UnstackableBranchFormat,
                 errors.UnstackableRepositoryFormat):
                 return
@@ -2306,7 +2306,7 @@
     i.e. stacking.
     """
 
-    def get_stacked_on(self):
+    def get_stacked_on_url(self):
         raise errors.UnstackableBranchFormat(self._format, self.base)
 
     def set_stacked_on(self, url):

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2008-07-14 07:47:45 +0000
+++ bzrlib/builtins.py	2008-07-15 04:43:19 +0000
@@ -862,7 +862,7 @@
             # We therefore need a try/except here and not just 'if stacked:'
             try:
                 note('Created new stacked branch referring to %s.' %
-                    branch.get_stacked_on())
+                    branch.get_stacked_on_url())
             except (errors.NotStacked, errors.UnstackableBranchFormat,
                 errors.UnstackableRepositoryFormat), e:
                 note('Branched %d revision(s).' % branch.revno())

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2008-07-14 07:47:45 +0000
+++ bzrlib/bzrdir.py	2008-07-15 04:43:19 +0000
@@ -1006,7 +1006,7 @@
                 stacked_branch_url = self.root_transport.base
             else:
                 try:
-                    stacked_branch_url = source_branch.get_stacked_on()
+                    stacked_branch_url = source_branch.get_stacked_on_url()
                 except (errors.NotStacked, errors.UnstackableBranchFormat,
                     errors.UnstackableRepositoryFormat):
                     stacked_branch_url = None

=== modified file 'bzrlib/info.py'
--- bzrlib/info.py	2008-06-03 05:19:26 +0000
+++ bzrlib/info.py	2008-07-15 04:43:19 +0000
@@ -142,7 +142,7 @@
     locs.add_url('parent branch', branch.get_parent())
     locs.add_url('submit branch', branch.get_submit_branch())
     try:
-        locs.add_url('stacked on', branch.get_stacked_on())
+        locs.add_url('stacked on', branch.get_stacked_on_url())
     except (errors.UnstackableBranchFormat, errors.UnstackableRepositoryFormat,
         errors.NotStacked):
         pass

=== modified file 'bzrlib/push.py'
--- bzrlib/push.py	2008-06-10 05:02:30 +0000
+++ bzrlib/push.py	2008-07-15 04:43:19 +0000
@@ -107,7 +107,7 @@
                 # if the from format is stackable, this will either work or
                 # trigger NotStacked. If it's not, an error will be given to
                 # the user.
-                br_from.get_stacked_on()
+                br_from.get_stacked_on_url()
             except errors.NotStacked:
                 pass
             # now we need to sprout the repository,

=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2008-07-07 10:31:06 +0000
+++ bzrlib/remote.py	2008-07-15 04:43:19 +0000
@@ -1319,7 +1319,7 @@
         self._ensure_real()
         return self._real_branch.get_physical_lock_status()
 
-    def get_stacked_on(self):
+    def get_stacked_on_url(self):
         """Get the URL this branch is stacked against.
 
         :raises NotStacked: If the branch is not stacked.
@@ -1329,7 +1329,7 @@
             stacking.
         """
         self._ensure_real()
-        return self._real_branch.get_stacked_on()
+        return self._real_branch.get_stacked_on_url()
 
     def lock_read(self):
         if not self._lock_mode:

=== modified file 'bzrlib/tests/blackbox/test_branch.py'
--- bzrlib/tests/blackbox/test_branch.py	2008-07-11 05:59:06 +0000
+++ bzrlib/tests/blackbox/test_branch.py	2008-07-15 04:43:19 +0000
@@ -107,7 +107,7 @@
         """
         new_branch = branch.Branch.open('newbranch')
         # The branch refers to the mainline
-        self.assertEqual(stacked_on, new_branch.get_stacked_on())
+        self.assertEqual(stacked_on, new_branch.get_stacked_on_url())
         # and the branch's work was pushed
         self.assertTrue(new_branch.repository.has_revision(branch_revid))
         # The newly committed revision shoud be present in the stacked branch,

=== modified file 'bzrlib/tests/blackbox/test_push.py'
--- bzrlib/tests/blackbox/test_push.py	2008-06-10 05:02:30 +0000
+++ bzrlib/tests/blackbox/test_push.py	2008-07-15 04:43:19 +0000
@@ -285,7 +285,7 @@
         """Assert that the branch 'published' has been published correctly."""
         published_branch = Branch.open('published')
         # The published branch refers to the mainline
-        self.assertEqual(stacked_on, published_branch.get_stacked_on())
+        self.assertEqual(stacked_on, published_branch.get_stacked_on_url())
         # and the branch's work was pushed
         self.assertTrue(published_branch.repository.has_revision(branch_revid))
 

=== modified file 'bzrlib/tests/branch_implementations/test_stacking.py'
--- bzrlib/tests/branch_implementations/test_stacking.py	2008-07-11 05:59:51 +0000
+++ bzrlib/tests/branch_implementations/test_stacking.py	2008-07-15 04:43:19 +0000
@@ -14,7 +14,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-"""Tests for Branch.get_stacked_on and set_stacked_on."""
+"""Tests for Branch.get_stacked_on_url and set_stacked_on."""
 
 from bzrlib import (
     bzrdir,
@@ -42,12 +42,12 @@
             branch.set_stacked_on(target.base)
         except old_format_errors:
             # if the set failed, so must the get
-            self.assertRaises(old_format_errors, branch.get_stacked_on)
+            self.assertRaises(old_format_errors, branch.get_stacked_on_url)
             return
         # now we have a stacked branch:
-        self.assertEqual(target.base, branch.get_stacked_on())
+        self.assertEqual(target.base, branch.get_stacked_on_url())
         branch.set_stacked_on(None)
-        self.assertRaises(errors.NotStacked, branch.get_stacked_on)
+        self.assertRaises(errors.NotStacked, branch.get_stacked_on_url)
 
     def assertRevisionInRepository(self, repo_path, revid):
         """Check that a revision is in a repository, disregarding stacking."""

=== modified file 'bzrlib/tests/test_branch.py'
--- bzrlib/tests/test_branch.py	2008-06-10 04:11:29 +0000
+++ bzrlib/tests/test_branch.py	2008-07-15 04:43:19 +0000
@@ -325,7 +325,7 @@
 
     def test_default_stacked_location(self):
         branch = self.make_branch('a', format=self.get_format_name())
-        self.assertRaises(errors.UnstackableBranchFormat, branch.get_stacked_on)
+        self.assertRaises(errors.UnstackableBranchFormat, branch.get_stacked_on_url)
 
 
 class TestBranch7(TestBranch67, TestCaseWithTransport):
@@ -349,17 +349,17 @@
 
     def _test_default_stacked_location(self):
         branch = self.make_branch('a', format=self.get_format_name())
-        self.assertRaises(errors.NotStacked, branch.get_stacked_on)
+        self.assertRaises(errors.NotStacked, branch.get_stacked_on_url)
 
     def test_stack_and_unstack(self):
         branch = self.make_branch('a', format=self.get_format_name())
         target = self.make_branch_and_tree('b', format=self.get_format_name())
         branch.set_stacked_on(target.branch.base)
-        self.assertEqual(target.branch.base, branch.get_stacked_on())
+        self.assertEqual(target.branch.base, branch.get_stacked_on_url())
         revid = target.commit('foo')
         self.assertTrue(branch.repository.has_revision(revid))
         branch.set_stacked_on(None)
-        self.assertRaises(errors.NotStacked, branch.get_stacked_on)
+        self.assertRaises(errors.NotStacked, branch.get_stacked_on_url)
         self.assertFalse(branch.repository.has_revision(revid))
 
     def test_open_opens_stacked_reference(self):

